﻿using System;
using System.Drawing;
using System.Windows.Forms;

using Steema.TeeChart.Drawing;
using Steema.TeeChart.Styles;
using Steema.TeeChart.Tools;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 마커 팁
        /// </summary>
        private MarksTip marksTip;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.showTipCheckBox.Checked = true;

            this.mouseActionComboBox.DropDownStyle = ComboBoxStyle.DropDownList;

            this.mouseActionComboBox.Items.Add("Move" );
            this.mouseActionComboBox.Items.Add("Click");

            this.mouseActionComboBox.SelectedIndex = 0;

            Text = "MarksTip 클래스 : 마커 팁 사용하기";

            this.tChart.Panel.Pen = new ChartPen(Color.Black);

            Bar bar = new Bar(this.tChart.Chart);

            bar.Marks.Visible = false;

            bar.FillSampleValues(8);

            this.marksTip = new MarksTip(this.tChart.Chart);

            this.marksTip.Series      = bar;
            this.marksTip.MouseAction = MarksTipMouseAction.Move;
            this.marksTip.MouseDelay  = 10; // 10 밀리초

            this.showTipCheckBox.CheckedChanged           += showTipCheckBox_CheckedChanged;
            this.mouseActionComboBox.SelectedIndexChanged += mouseActionComboBox_SelectedIndexChanged;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 팁 표시 체크 박스 체크 변경시 처리하기 - showTipCheckBox_CheckedChanged(sender, e)

        /// <summary>
        /// 팁 표시 체크 박스 체크 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void showTipCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            this.marksTip.Active = this.showTipCheckBox.Checked;

            this.mouseActionComboBox.Enabled = this.marksTip.Active;
        }

        #endregion
        #region 마우스 액션 콤보 박스 선택 인덱스 변경시 처리하기 - mouseActionComboBox_SelectedIndexChanged(sender, e)

        /// <summary>
        /// 마우스 액션 콤보 박스 선택 인덱스 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void mouseActionComboBox_SelectedIndexChanged(object sender, EventArgs e)
        {
            this.marksTip.MouseAction = (MarksTipMouseAction)this.mouseActionComboBox.SelectedIndex;
        }

        #endregion
    }
}